@@ -1,3 +1,5 @@
+if(getRversion() >= "3.1.0") utils::suppressForeignCheck("localfunc")
+
 freeall.rphast <- function() {
   invisible(.Call("rph_free_all"))
 }
@@ -5,7 +7,8 @@ freeall.rphast <- function() {
 .Call.rphast <- function(func, ...) {
   .Call("rph_new_mem_handler")
   on.exit(freeall.rphast())
-  .Call(func, ...)
+  localfunc <- func
+  .Call(localfunc, ...)
 }
 
 
